##### Package <em>apb_pandas_utils</em>

Modules to add functionality over `pandas` and `geopandas` 

Requires `GDAL` library version 3.6<=3.10 and instant client Oracle installed.

To install:
```shell
pip install apb_pandas_utils
```

Documentation here [apb_pandas_utils](https://serveis.portdebarcelona.cat/generic_python_packages/apb_pandas_utils.html)
